package com.fastbee.data.controller.gis;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fastbee.common.annotation.Log;
import com.fastbee.common.core.controller.BaseController;
import com.fastbee.common.core.domain.AjaxResult;
import com.fastbee.common.enums.BusinessType;
import com.fastbee.ggroup.domain.GSiteSluiceInfo;
import com.fastbee.ggroup.service.IGSiteSluiceInfoService;
import com.fastbee.common.utils.poi.ExcelUtil;
import com.fastbee.common.core.page.TableDataInfo;

/**
 * 水闸基本信息Controller
 *
 * @author kerwincui
 * @date 2024-10-31
 */
@RestController
@RequestMapping("/ggroup/info")
@Api(tags = "水闸基本信息")
public class GSiteSluiceInfoController extends BaseController
{
    @Autowired
    private IGSiteSluiceInfoService gSiteSluiceInfoService;

/**
 * 查询水闸基本信息列表
 */
@PreAuthorize("@ss.hasPermi('ggroup:info:list')")
@GetMapping("/list")
@ApiOperation("查询水闸基本信息列表")
    public TableDataInfo list(GSiteSluiceInfo gSiteSluiceInfo)
    {
        startPage();
        List<GSiteSluiceInfo> list = gSiteSluiceInfoService.selectGSiteSluiceInfoList(gSiteSluiceInfo);
        return getDataTable(list);
    }

    /**
     * 导出水闸基本信息列表
     */
    @ApiOperation("导出水闸基本信息列表")
    @PreAuthorize("@ss.hasPermi('ggroup:info:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, GSiteSluiceInfo gSiteSluiceInfo)
    {
        List<GSiteSluiceInfo> list = gSiteSluiceInfoService.selectGSiteSluiceInfoList(gSiteSluiceInfo);
        ExcelUtil<GSiteSluiceInfo> util = new ExcelUtil<GSiteSluiceInfo>(GSiteSluiceInfo.class);
        util.exportExcel(response, list, "水闸基本信息数据");
    }

    /**
     * 获取水闸基本信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('ggroup:info:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取水闸基本信息详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gSiteSluiceInfoService.selectGSiteSluiceInfoById(id));
    }

    /**
     * 新增水闸基本信息
     */
    @PreAuthorize("@ss.hasPermi('ggroup:info:add')")
    @PostMapping
    @ApiOperation("新增水闸基本信息")
    public AjaxResult add(@RequestBody GSiteSluiceInfo gSiteSluiceInfo)
    {
        return toAjax(gSiteSluiceInfoService.insertGSiteSluiceInfo(gSiteSluiceInfo));
    }

    /**
     * 修改水闸基本信息
     */
    @PreAuthorize("@ss.hasPermi('ggroup:info:edit')")
    @PutMapping
    @ApiOperation("修改水闸基本信息")
    public AjaxResult edit(@RequestBody GSiteSluiceInfo gSiteSluiceInfo)
    {
        return toAjax(gSiteSluiceInfoService.updateGSiteSluiceInfo(gSiteSluiceInfo));
    }

    /**
     * 删除水闸基本信息
     */
    @PreAuthorize("@ss.hasPermi('ggroup:info:remove')")
    @DeleteMapping("/{ids}")
    @ApiOperation("删除水闸基本信息")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gSiteSluiceInfoService.deleteGSiteSluiceInfoByIds(ids));
    }
}
