package com.fastbee.ggroup.service.impl;

import java.util.List;
import com.fastbee.common.utils.DateUtils;
import com.fastbee.ggroup.mapper.GSiteSluiceInfoMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.ggroup.domain.GSiteSluiceInfo;
import com.fastbee.ggroup.service.IGSiteSluiceInfoService;

/**
 * 水闸基本信息Service业务层处理
 * 
 * @author kerwincui
 * @date 2024-10-31
 */
@Service
public class GSiteSluiceInfoServiceImpl implements IGSiteSluiceInfoService 
{
    @Autowired
    private GSiteSluiceInfoMapper gSiteSluiceInfoMapper;

    /**
     * 查询水闸基本信息
     * 
     * @param id 水闸基本信息主键
     * @return 水闸基本信息
     */
    @Override
    public GSiteSluiceInfo selectGSiteSluiceInfoById(Long id)
    {
        return gSiteSluiceInfoMapper.selectGSiteSluiceInfoById(id);
    }

    /**
     * 查询水闸基本信息列表
     * 
     * @param gSiteSluiceInfo 水闸基本信息
     * @return 水闸基本信息
     */
    @Override
    public List<GSiteSluiceInfo> selectGSiteSluiceInfoList(GSiteSluiceInfo gSiteSluiceInfo)
    {
        return gSiteSluiceInfoMapper.selectGSiteSluiceInfoList(gSiteSluiceInfo);
    }

    /**
     * 新增水闸基本信息
     * 
     * @param gSiteSluiceInfo 水闸基本信息
     * @return 结果
     */
    @Override
    public int insertGSiteSluiceInfo(GSiteSluiceInfo gSiteSluiceInfo)
    {
        gSiteSluiceInfo.setCreateTime(DateUtils.getNowDate());
        return gSiteSluiceInfoMapper.insertGSiteSluiceInfo(gSiteSluiceInfo);
    }

    /**
     * 修改水闸基本信息
     * 
     * @param gSiteSluiceInfo 水闸基本信息
     * @return 结果
     */
    @Override
    public int updateGSiteSluiceInfo(GSiteSluiceInfo gSiteSluiceInfo)
    {
        gSiteSluiceInfo.setUpdateTime(DateUtils.getNowDate());
        return gSiteSluiceInfoMapper.updateGSiteSluiceInfo(gSiteSluiceInfo);
    }

    /**
     * 批量删除水闸基本信息
     * 
     * @param ids 需要删除的水闸基本信息主键
     * @return 结果
     */
    @Override
    public int deleteGSiteSluiceInfoByIds(Long[] ids)
    {
        return gSiteSluiceInfoMapper.deleteGSiteSluiceInfoByIds(ids);
    }

    /**
     * 删除水闸基本信息信息
     * 
     * @param id 水闸基本信息主键
     * @return 结果
     */
    @Override
    public int deleteGSiteSluiceInfoById(Long id)
    {
        return gSiteSluiceInfoMapper.deleteGSiteSluiceInfoById(id);
    }
}
